
DeNova Safelog
--------------

Get instant multithread, multiprocess, and multiprogram safe logs. Safelog also
has a much simpler and more powerful api than standard python logging.


Full Description
----------------

Learn more about [DeNova Safelog](https://denova.com/open_source/safelog/)

Install Safelog's systemd [service file](https://denova.com/open_source/safelog/get_app/safelog.service)
to make sure "safelog" is available for all of your python apps. If you are installing
Safelog from github, be sure to also install the "denova" package from PyPI.
